pub struct VMNativeCallFunction(/* private fields */);Expand description
A function pointer that exposes the native calling convention.
Different Wasm function types end up mapping to different Rust function
types, so this isn’t simply a type alias the way that VMArrayCallFunction
is.
This is the default calling convention for the target (e.g. System-V or fast-call) except multiple return values are handled by returning the first return value in a register and everything else through a return-pointer.